ColorPrimaries

Enum ColorPrimaries 

#[repr(C)]
pub enum ColorPrimaries { BT709 = 1, BT470M = 4, BT470BG = 5, BT601 = 6, GenericFilm = 8, BT2020 = 9, XYZ = 10, SMPTE431 = 11, SMPTE432 = 12, EBU3213 = 22, }
Supported Color Primaries

As defined by “Color primaries” section of ISO/IEC 23091-4/ITU-T H.273

Variants



BT709 = 1

BT.709, sRGB, sYCC. BT.709 is the standard for high definition (HD) television; sRGB is the most common color space used for computer displays.



BT470M = 4

BT.470 System M, NTSC (standard definition television in the United States) (historical)



BT470BG = 5

BT.470 System B, G; BT.601; BT.1358 625; BT.1700 625 PAL and 625 SECAM (historical)



BT601 = 6

BT.601-7 525 (SMPTE 170 M) and SMPTE 240M (historical)



GenericFilm = 8

ITU-T H.264



BT2020 = 9

BT.2020; BT.2100. Used for ultra-high definition (4K) High Dynamic Range (HDR) video, these have a very wide color gamut and support 10-bit and 12-bit color component depths.



XYZ = 10

CIE 1921 XYZ; SMPTE ST 428 (D-Cinema Distribution Master: Image characteristics). Defines the uncompressed image characteristics for DCDM.



SMPTE431 = 11

SMPTE RP 431 (D-Cinema Quality: Reference projector and environment).



SMPTE432 = 12

SMPTE EG 432-1 (Digital Source Processing: Color Processing for D-Cinema).



EBU3213 = 22

EBU Tech. 3213-E