Planes

Enum Planes 

pub enum Planes<'a> {
    YuvPlanes8 {
        y: ImgRef<'a, u8>,
        u: ImgRef<'a, u8>,
        v: ImgRef<'a, u8>,
        chroma_sampling: ChromaSampling,
    },
    Mono8(ImgRef<'a, u8>),
    YuvPlanes16 {
        y: ImgRef<'a, [u8; 2]>,
        u: ImgRef<'a, [u8; 2]>,
        v: ImgRef<'a, [u8; 2]>,
        chroma_sampling: ChromaSampling,
        depth: Depth,
    },
    Mono16(ImgRef<'a, [u8; 2]>, Depth),
}
It’s an enum, because frames may have different pixel formats

Variants



YuvPlanes8

8-bit YUV (YCbCr, YCgCo, etc.). This is a collection of 3 planes. Each may have a different size depending on chroma_sampling.

Consult matrix_coefficients() for meaning of these channels

Fields

y: ImgRef<'a, u8>
u: ImgRef<'a, u8>
v: ImgRef<'a, u8>
chroma_sampling: ChromaSampling


Mono8(ImgRef<'a, u8>)

8-bit grayscale



YuvPlanes16

10/12/16-bit color. Not subsampled. See depth field for actual range of pixels used.

It’s not u16, because it’s not guaranteed to be aligned. Use u16::from_ne_bytes() or ptr::read_unaligned.

Fields

y: ImgRef<'a, [u8; 2]>
u: ImgRef<'a, [u8; 2]>
v: ImgRef<'a, [u8; 2]>
chroma_sampling: ChromaSampling
depth: Depth


Mono16(ImgRef<'a, [u8; 2]>, Depth)

10/12/16-bit grayscale. It’s not u16, because it’s not guaranteed to be aligned. Use u16::from_ne_bytes() or ptr::read_unaligned.