Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
AOM decoder context

Implementations

Source

impl Decoder

pub fn new(cfg: &Config) -> Result<Self>

Create a new decoder

pub fn frame_meta<'a>(&'a mut self, av1_data: &[u8]) -> Result<FrameMeta>

This parses the AV1 data independently of decode_frame

pub fn decode_frame<'a>( &'a mut self, av1_data: &[u8], ) -> Result<FrameTempRef<'a>>

Take AV1-compressed data and decode a single frame into raw frame data (YUV pixels). This is for AVIF, and can’t handle video.

The returned frame is temporary. You must copy data out of it and drop it before decoding other files.

See yuv crate for conversion to RGB.